==> nutrient-2022-0.1.20.tgz: package/src/port.ts <==
import Connection from "./connection.js";
import { Events } from "./events.js";
import Node from "./node.js";
import Observer from "./observer.js";

export enum PortType {
    Output,
    Input,
    InputMulti
}

type ConnectionEntries = [number, Connection][];

class Port {
    key: string;
    type: PortType;
    ownerNode: Node;
    connections: ConnectionEntries = [];

    constructor(key: string, type: PortType, ownerNode: Node) {
        this.key = key;
        this.type = type;
        this.ownerNode = ownerNode;
    }

    getConnectionIndex(id: number) {
        let len = this.connections.length;
        for (let i = 0; i < len; i++) {
            if (this.connections[i][0] == id) {
                return i;
            }
        }
        return -1;
    }

    hasConnections() {
        return this.connections.length > 0;
    }

    createConnection(id: number, oppositePort: Port, inputIndex: number = 0) {
        //let id = IDGenerator.next();
        let connection;
        if (this.type == PortType.Output) {
            connection = new Connection(id, this, oppositePort);
        }
        else {
            connection = new Connection(id, oppositePort, this);
        }

        this.connections.splice(inputIndex, 0, [id, connection]);
        oppositePort.connections.splice(inputIndex, 0, [id, connection]);

        //this.connections.push([id, connection]);
        //oppositePort.connections.push([id, connection]);

        Observer.triggerEvent(Events.OnConnectPort, connection);
        return connection;
    }

    removeConnection(id: number): Connection {
        let index = this.getConnectionIndex(id);
        let connection = this.connections[index][1];
        this.connections.splice(index, 1);
        Observer.triggerEvent(Events.OnDisconnectPort, connection);
        return connection;
    }

    getConnection(id: number) {
        let index = this.getConnectionIndex(id);
        return this.connections[index][1];
    }

    getName() {
        let dir: "inputs" | "outputs" = this.type == PortType.Output ? "outputs" : "inputs";
        return this.ownerNode.component.data[dir]![this.key].name;
    }

    getComponentPort() {
        let port = this.type == PortType.Output
            ? this.ownerNode.component.data.outputs
            : this.ownerNode.component.data.inputs;

        return port![this.key];
    }
}

export default Port;

==> nutrient-2022-0.1.26.tgz: package/src/port.ts <==
import Connection from "./connection.js";
import { Events } from "./events.js";
import Node from "./node.js";
import observer from "./observer.js";

export enum PortType {
    Output,
    Input,
    InputMulti
}

type ConnectionEntries = [number, Connection][];

class Port {
    key: string;
    type: PortType;
    ownerNode: Node;
    connections: ConnectionEntries = [];

    constructor(key: string, type: PortType, ownerNode: Node) {
        this.key = key;
        this.type = type;
        this.ownerNode = ownerNode;
    }

    getConnectionIndex(id: number) {
        let len = this.connections.length;
        for (let i = 0; i < len; i++) {
            if (this.connections[i][0] == id) {
                return i;
            }
        }
        return -1;
    }

    hasConnections() {
        return this.connections.length > 0;
    }

    createConnection(id: number, oppositePort: Port, inputIndex: number = 0) {
        //let id = IDGenerator.next();
        let connection;
        if (this.type == PortType.Output) {
            connection = new Connection(id, this, oppositePort);
        }
        else {
            connection = new Connection(id, oppositePort, this);
        }

        this.connections.splice(inputIndex, 0, [id, connection]);
        oppositePort.connections.splice(inputIndex, 0, [id, connection]);

        //this.connections.push([id, connection]);
        //oppositePort.connections.push([id, connection]);

        observer.triggerEvent(Events.OnConnectPort, connection);
        return connection;
    }

    removeConnection(id: number): Connection {
        let index = this.getConnectionIndex(id);
        let connection = this.connections[index][1];
        this.connections.splice(index, 1);
        observer.triggerEvent(Events.OnDisconnectPort, connection);
        return connection;
    }

    getConnection(id: number) {
        let index = this.getConnectionIndex(id);
        return this.connections[index][1];
    }

    getName() {
        let dir: "inputs" | "outputs" = this.type == PortType.Output ? "outputs" : "inputs";
        return this.ownerNode.component.data[dir]![this.key].name;
    }

    getComponentPort() {
        let port = this.type == PortType.Output
            ? this.ownerNode.component.data.outputs
            : this.ownerNode.component.data.inputs;

        return port![this.key];
    }
}

export default Port;
